@@ -256,7 +256,7 @@ char *cp_racename;
       if (gB.race)
       {
 	gB.alloc_size += RACE_BLK_SIZE;
-	gB.race = (struct battle_race *) realloc(gB.race, 
+	gB.race = (struct battle_race *) REALLOC(gB.race, 
 	  gB.alloc_size * sizeof(struct battle_race));
 	for (i = gB.num_races; i < gB.alloc_size; i++)
 	{
@@ -269,7 +269,7 @@ char *cp_racename;
       {
 	gB.num_races = 1;
 	gB.alloc_size = RACE_BLK_SIZE;
-	gB.race = (struct battle_race *) calloc(gB.alloc_size, sizeof(struct battle_race));
+	gB.race = (struct battle_race *) CALLOC(gB.alloc_size, sizeof(struct battle_race));
 	next = 0;
       }
     }
@@ -331,7 +331,7 @@ int i_raceid;
       if (gB.race[i_raceid].group)
       {
 	gB.race[i_raceid].alloc_size += RACE_BLK_SIZE;
-	gB.race[i_raceid].group = (struct battle_group *) realloc(gB.race[i_raceid].group, 
+	gB.race[i_raceid].group = (struct battle_group *) REALLOC(gB.race[i_raceid].group, 
 	  gB.race[i_raceid].alloc_size * sizeof(struct battle_group));
 
 	for (i = gB.race[i_raceid].num_groups; i < gB.race[i_raceid].alloc_size; i++)
@@ -353,7 +353,7 @@ int i_raceid;
       {
 	gB.race[i_raceid].alloc_size = GROUP_BLK_SIZE;
 	gB.race[i_raceid].group = (struct battle_group *) 
-	  calloc(gB.race[i_raceid].alloc_size, sizeof(struct battle_group));
+	  CALLOC(gB.race[i_raceid].alloc_size, sizeof(struct battle_group));
 	gB.race[i_raceid].num_groups = 1;
 	next = 0;
       }
@@ -723,9 +723,9 @@ char *cp_filename;
     {
       /* Collect data on all groups involved */
       fightgroups = (struct battle_group **) 
-	calloc(ngroups, sizeof(struct battle_group *));
-      shipstofire = (int *) calloc(ngroups, sizeof(int));
-      groupplayers = (int *) calloc(ngroups, sizeof(int));
+	CALLOC(ngroups, sizeof(struct battle_group *));
+      shipstofire = (int *) CALLOC(ngroups, sizeof(int));
+      groupplayers = (int *) CALLOC(ngroups, sizeof(int));
 
       i = 0;
       for (r = 0; r < gB.num_races; r++)
