@@ -453,13 +453,13 @@ group_alloc()
     if (gG.group == 0)
     {
       gG.max_groups = BLKSIZE;
-      gG.group = (struct groups *) calloc(gG.max_groups,
+      gG.group = (struct groups *) CALLOC(gG.max_groups,
 	sizeof(struct groups));
     }
     else
     {
       gG.max_groups += BLKSIZE;
-      gG.group = (struct groups *) realloc(gG.group, 
+      gG.group = (struct groups *) REALLOC(gG.group, 
 	gG.max_groups * sizeof(struct groups));
 
       for (i = gG.max_groups - BLKSIZE; i < gG.max_groups; i++) 
@@ -784,7 +784,7 @@ int i_race;
 
     once = 0;
 
-    pl = (int *) malloc(g_num_planets * sizeof(int));
+    pl = (int *) MALLOC(g_num_planets * sizeof(int));
     if (!pl)
     {
       char msg[128];
