@@ -943,15 +943,7 @@ FILE *fp;
     if ((p1 = PlanetAtCursor(QUERY)) == -1)
       return(-1);
 
-    darray = (struct sorted *) malloc(sizeof(struct sorted) * g_num_planets);
-    if (!darray)
-    {
-      char msg[128];
-      sprintf(msg,
-	"PlanetDisplayDistAll(): Out of memory trying to allocate %d structs\n", 
-	g_num_planets);
-      abort_program(msg);
-    }
+    darray = (struct sorted *) MALLOC(sizeof(struct sorted) * g_num_planets);
     /* get all distances */
     for (p2 = 0; p2 < g_num_planets; p2++)
     {
